**dart_board**
==============

.. image:: https://img.shields.io/badge/GitHub-astroJeff%2Fdart_board-blue.svg?style=flat
    :target: https://github.com/astroJeff/dart_board
.. image:: https://readthedocs.org/projects/dart-board/badge/?version=latest
  :target: http://dart-board.readthedocs.io/en/latest/?badge=latest
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
  :target: https://github.com/astroJeff/dart_board/blob/master/LICENSE
.. image:: http://img.shields.io/badge/arXiv-1710.11030-orange.svg?style=flat
      :target: http://arxiv.org/abs/1710.11030
.. image:: https://zenodo.org/badge/86565955.svg
   :target: https://zenodo.org/badge/latestdoi/86565955


``dart_board`` is a statistical wrapper to rapid binary evolution codes. The default prescriptions are ``BSE`` (Hurley, Tout, & Pols 2002) for binary evolution and ``emcee`` (Foreman-Mackey et al. 2013) for the MCMC sampling method. For a description of the code, see our ArXiv posting: http://adsabs.harvard.edu/abs/2017arXiv171011030A

**Documentation**
-----------------  

For documentation, `read the docs <http://dart-board.readthedocs.io/>`_.


**Issues**
----------

If you find any problems with ``dart_board``, please `let us know <https://github.com/astroJeff/dart_board/issues/new>`_.
Or you can e-mail any questions to andrews@physics.uoc.gr.


**Citation**
------------

If you use ``dart_board`` in your research, please cite `our paper <http://cdsads.u-strasbg.fr/abs/2017arXiv171011030A>`_.


**License**
-----------

Copyright (c) 2017-2018 Jeff J. Andrews.

dart_board is made freely available under the MIT License. For details see
the LICENSE file.
